@@ -46,12 +46,12 @@ from packaging.utils import canonicalize_name, parse_wheel_filename
 from packaging.version import Version
 
 # this package
-from pypi_json.typehints import DistributionPackageDict, FileURL, ProjectInfoDict, Self
+from pypi_json.typehints import DistributionPackageDict, FileURL, ProjectInfoDict, Self, VulnerabilityInfoDict
 
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2021 Dominic Davis-Foster"
 __license__: str = "MIT License"
-__version__: str = "0.1.1"
+__version__: str = "0.2.0"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = ["PyPIJSON", "ProjectMetadata", "USER_AGENT"]
@@ -99,6 +99,13 @@ class ProjectMetadata(NamedTuple):
 	#: A list of release artifacts associated with this version.
 	urls: List[DistributionPackageDict]
 
+	vulnerabilities: List[VulnerabilityInfoDict] = []
+	"""
+	Details of vulnerabilities from the `Open Source Vulnerabilities project <https://osv.dev/>`_.
+
+	(*New in version 0.2.0*)
+	"""
+
 	@property
 	def name(self) -> str:
 		"""
